--[[
******************************************************************
Script to copy the plug-in installation file to a known location where it can
be found by My XPS Card Printer application.

 ***** IMPORTANT NOTE *****
When this script is called at install time the calling script should set bOverwriteFiles to true.
This script should not be called at uninstall time.
******************************************************************
]]--

fDebug("\r\nCopying plugin install...");
-- initialize local variables.
local bContinue = true;
local error = 0;
local pathCommonAppDataFolder = Shell.GetFolder(SHF_APPLICATIONDATA_COMMON);
local pathRootDriverFolder = pathCommonAppDataFolder.."\\Datacard\\XPS Card Printer";
local pathPluginInstall = pathRootDriverFolder.."\\Plugin";

-- Make sure the overwrite flag is set to a valid state (true).
-- This protects against callers not implementing this variable and having its value be nil.
if (bOverwriteFiles ~= false) then
	bOverwriteFiles = true;
end
		
--[[
******************************************************************
Create folder to hold the plugin installation. 
******************************************************************
 ]]--
if not (Folder.DoesExist(pathPluginInstall)) then
	Folder.Create(pathPluginInstall);		
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("Creating plugin install folder at "..pathPluginInstall.." failed with error: "..error);
	end	
end

--[[
******************************************************************
Copy the plug-in installation file. 
******************************************************************
 ]]--	 
if bContinue then
	File.Copy(_SourceFolder.."\\Plug-in\\*.*", pathPluginInstall, false, bOverwriteFiles, false, false, nil);
	error = Application.GetLastError();
	if (error ~= 0) then
		bContinue = false;
		fDebug("Copying plugin install file to "..pathPluginInstall.." failed with error: "..error);
	end
end	


-- Send a signal back to the main script using the bContinueInstall flag.
if (bContinue) then
	bContinueInstall = true;
	fDebug("SUCCESS: Plugin installation copied to "..pathPluginInstall);
else
	bContinueInstall = false;
	fDebug("FAIL: Plugin installation not copied.");
end