--[[ 
Script to determine if the Evergreen driver is installed.

 **** MODIFICATION HISTORY ****
9-16-11: Ken Fischer: PTR 580: Added kernal32 dll calls on 64 bit OS's to turn off redirection (and turn it back on).  Without this call the code looking in the
System32 folder was actually looking in the SysWow64 folder and not finding the driver.

9-14-11: Ken Fischer: PTR 512: Modified to resolve issue where share client is detected as an installed driver, even though it is not a full driver.
Need to find a driver file that is only installed on the share host.
Sangeeta provided the answer.  The file I am looking for is OK but the location should be changed to the System32 folder instead of the 3 folder.
]]--

fDebug("\r\n\Detecting if driver is installed...");
IsDriverInstalled = false; -- returned to the calling script
strDriverVersion = "";  -- returned to the calling script
local strDriverFileToCheck = "dxp01mon.dll";

if (System.Is64BitOS()) then -- if 64 bit OS turn off redirection
  DLL.CallFunction("kernel32.dll", "Wow64DisableWow64FsRedirection", "\""..Application.GetWndHandle().."\"", DLL_RETURN_TYPE_LONG, DLL_CALL_STDCALL);
end

fDebug("  Looking in folder: ".._SystemFolder.." for file: "..strDriverFileToCheck);

if (File.DoesExist(_SystemFolder.."\\"..strDriverFileToCheck)) then
	fDebug("  Driver file found.");
	IsDriverInstalled = true;
	DriverFileInfo = File.GetVersionInfo(_SystemFolder.."\\"..strDriverFileToCheck);
	-- Get the last error code
	nError = Application.GetLastError();
	if nError == 0 then
    	-- There was not an error
    	strDriverVersion = DriverFileInfo.ProductVersion;
    	fDebug("  Driver version found.\r\n");
	else
    	-- There was an error.
    	strDriverVersion = "?";
    	fDebug("  Error getting driver version. Error number: "..nError);
	end
else
	fDebug("  No driver file found.\r\n");
end

if (System.Is64BitOS()) then -- if 64 bit OS turn redirection back on.
  DLL.CallFunction("kernel32.dll", "Wow64RevertWow64FsRedirection", "\""..Application.GetWndHandle().."\"" , DLL_RETURN_TYPE_LONG, DLL_CALL_STDCALL);
end
